==> typegram-0.0.1-py3-none-any.whl: typegram/api/types/updateBroadcastRevenueTransactions.py <==

#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram.api import ayiin, functions
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class UpdateBroadcastRevenueTransactions(Object):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~typegram.api.ayiin.Update`.

    Details:
        - Layer: ``181``
        - ID: ``DFD961F5``

peer (:obj:`Peer<typegram.api.ayiin.Peer>`):
                    N/A
                
        balances (:obj:`BroadcastRevenueBalances<typegram.api.ayiin.BroadcastRevenueBalances>`):
                    N/A
                
    Functions:
        This object can be returned by 7 functions.

        .. currentmodule:: typegram.api.functions

        .. autosummary::
            :nosignatures:

            .X
            .RpcDropAnswer
            .Bool
            .Authorization
            .PeerNotifySettings
            .User
            .Vector<SecureValue>
            .SecureValue
            .Updates
            .WallPaper
            .Document
            .Theme
            .Vector<WallPaper>
            .GlobalPrivacySettings
            .EmojiList
            .BusinessChatLink
            .ReactionsNotifySettings
            .Vector<User>
            .Vector<Bool>
            .Vector<int>
            .Vector<ReceivedNotifyMessage>
            .EncryptedChat
            .Vector<long>
            .MessageMedia
            .ExportedChatInvite
            .ChatInvite
            .Vector<StickerSetCovered>
            .EncryptedFile
            .ChatOnlines
            .EmojiKeywordsDifference
            .Vector<EmojiLanguage>
            .EmojiURL
            .UrlAuthResult
            .Vector<ReadParticipantDate>
            .AttachMenuBots
            .AttachMenuBotsBot
            .WebViewResult
            .SimpleWebViewResult
            .WebViewMessageSent
            .Vector<Document>
            .AppWebViewResult
            .OutboxReadDate
            .Vector<FactCheck>
            .Vector<FileHash>
            .ExportedMessageLink
            .DataJSON
            .Vector<BotCommand>
            .BotMenuButton
            .Vector<PremiumGiftCodeOption>
            .LangPackDifference
            .Vector<LangPackString>
            .Vector<LangPackLanguage>
            .LangPackLanguage
            .StatsGraph
            .ExportedChatlistInvite
            .Vector<Peer>
            .ExportedStoryLink
            .SmsJob
            .ResPQ
            .P_Q_inner_data
            .BindAuthKeyInner
            .Server_DH_Params
            .Server_DH_inner_data
            .Client_DH_Inner_Data
            .Set_client_DH_params_answer
    """

    __slots__: List[str] = ["peer", "balances"]

    ID = 0xdfd961f5
    QUALNAME = "functions.types.Update"

    def __init__(self, *, peer: "ayiin.Peer", balances: "ayiin.BroadcastRevenueBalances") -> None:
        
                self.peer = peer  # Peer
        
                self.balances = balances  # BroadcastRevenueBalances

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "UpdateBroadcastRevenueTransactions":
        # No flags
        
        peer = Object.read(b)
        
        balances = Object.read(b)
        
        return UpdateBroadcastRevenueTransactions(peer=peer, balances=balances)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.peer.write())
        
        b.write(self.balances.write())
        
        return b.getvalue()

==> typegram-0.0.2-py3-none-any.whl: typegram/api/types/updateBroadcastRevenueTransactions.py <==

#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram import api
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class UpdateBroadcastRevenueTransactions(Object):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~typegram.api.ayiin.Update`.

    Details:
        - Layer: ``181``
        - ID: ``DFD961F5``

peer (:obj:`Peer<typegram.api.ayiin.Peer>`):
                    N/A
                
        balances (:obj:`BroadcastRevenueBalances<typegram.api.ayiin.BroadcastRevenueBalances>`):
                    N/A
                
    """

    __slots__: List[str] = ["peer", "balances"]

    ID = 0xdfd961f5
    QUALNAME = "types.updateBroadcastRevenueTransactions"

    def __init__(self, *, peer: "api.ayiin.Peer", balances: "api.ayiin.BroadcastRevenueBalances") -> None:
        
                self.peer = peer  # Peer
        
                self.balances = balances  # BroadcastRevenueBalances

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "UpdateBroadcastRevenueTransactions":
        # No flags
        
        peer = Object.read(b)
        
        balances = Object.read(b)
        
        return UpdateBroadcastRevenueTransactions(peer=peer, balances=balances)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.peer.write())
        
        b.write(self.balances.write())
        
        return b.getvalue()
